aboutsummaryrefslogtreecommitdiff
path: root/cast/sender/cast_platform_client.h
diff options
context:
space:
mode:
authorAbraham Corea Diaz <abrahamcd@google.com>2021-07-02 20:53:57 +0000
committerOpenscreen LUCI CQ <openscreen-scoped@luci-project-accounts.iam.gserviceaccount.com>2021-07-03 02:56:05 +0000
commit9d6aade8df4477ef616f81b29cf91eb157c3686c (patch)
tree731d6935376cc4f3348767d4c2177b8949d8a8c4 /cast/sender/cast_platform_client.h
parent223797e8b6f8e52f3b84c6e4240e2d941b46c6cb (diff)
downloadopenscreen-9d6aade8df4477ef616f81b29cf91eb157c3686c.tar.gz
Rename Device to Receiver
This patch renames relevant usages of Device to Receiver. Bug: b/155337619 Change-Id: Ib21c99ee7ceb6a7f73247e00c0e2638a92c342c1 Reviewed-on: https://chromium-review.googlesource.com/c/openscreen/+/2998268 Commit-Queue: Jordan Bayles <jophba@chromium.org> Reviewed-by: Jordan Bayles <jophba@chromium.org>
Diffstat (limited to 'cast/sender/cast_platform_client.h')
-rw-r--r--cast/sender/cast_platform_client.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/cast/sender/cast_platform_client.h b/cast/sender/cast_platform_client.h
index 0acb35a7..c80a8b95 100644
--- a/cast/sender/cast_platform_client.h
+++ b/cast/sender/cast_platform_client.h
@@ -41,15 +41,15 @@ class CastPlatformClient final : public CastMessageHandler {
~CastPlatformClient() override;
// Requests availability information for |app_id| from the receiver identified
- // by |device_id|. |callback| will be called exactly once with a result.
- absl::optional<int> RequestAppAvailability(const std::string& device_id,
+ // by |receiver_id|. |callback| will be called exactly once with a result.
+ absl::optional<int> RequestAppAvailability(const std::string& receiver_id,
const std::string& app_id,
AppAvailabilityCallback callback);
// Notifies this object about general receiver connectivity or property
// changes.
- void AddOrUpdateReceiver(const ReceiverInfo& device, int socket_id);
- void RemoveReceiver(const ReceiverInfo& device);
+ void AddOrUpdateReceiver(const ReceiverInfo& receiver, int socket_id);
+ void RemoveReceiver(const ReceiverInfo& receiver);
void CancelRequest(int request_id);
@@ -70,7 +70,7 @@ class CastPlatformClient final : public CastMessageHandler {
CastSocket* socket,
::cast::channel::CastMessage message) override;
- void HandleResponse(const std::string& device_id,
+ void HandleResponse(const std::string& receiver_id,
int request_id,
const Json::Value& message);
@@ -82,9 +82,9 @@ class CastPlatformClient final : public CastMessageHandler {
const std::string sender_id_;
VirtualConnectionRouter* const virtual_conn_router_;
- std::map<std::string /* device_id */, int> socket_id_by_device_id_;
- std::map<std::string /* device_id */, PendingRequests>
- pending_requests_by_device_id_;
+ std::map<std::string /* receiver_id */, int> socket_id_by_receiver_id_;
+ std::map<std::string /* receiver_id */, PendingRequests>
+ pending_requests_by_receiver_id_;
const ClockNowFunctionPtr clock_;
TaskRunner* const task_runner_;